@@ -170,6 +170,7 @@ class ExitWaveImageSimulator(object):
         drift = self.scan.shift_delta[index]
         beam_tilt_theta = self.scan.beam_tilt_theta[index]
         beam_tilt_phi = self.scan.beam_tilt_phi[index]
+        exposure_time = self.scan.exposure_time[index]
 
         # The field of view
         nx = self.microscope.detector.nx
@@ -243,13 +244,14 @@ class ExitWaveImageSimulator(object):
         fov_xmax = fov_xmin + x_fov + 2 * offset
         fov_ymin = origin[1] - offset
         fov_ymax = fov_ymin + y_fov + 2 * offset
-        select = (
-            (atoms.data["x"] >= fov_xmin)
-            & (atoms.data["x"] <= fov_xmax)
-            & (atoms.data["y"] >= fov_ymin)
-            & (atoms.data["y"] <= fov_ymax)
-        )
-        atoms.data = atoms.data[select]
+        if len(atoms.data) > 0:
+            select = (
+                (atoms.data["x"] >= fov_xmin)
+                & (atoms.data["x"] <= fov_xmax)
+                & (atoms.data["y"] >= fov_ymin)
+                & (atoms.data["y"] <= fov_ymax)
+            )
+            atoms.data = atoms.data[select]
 
         # Translate for the detector
         input_multislice.spec_atoms = atoms.translate(
@@ -257,18 +259,19 @@ class ExitWaveImageSimulator(object):
         ).to_multem()
         logger.info("   Got spec atoms")
 
-        print(
-            "Atoms X min/max: %.1f, %.1f"
-            % (atoms.data["x"].min(), atoms.data["x"].max())
-        )
-        print(
-            "Atoms Y min/max: %.1f, %.1f"
-            % (atoms.data["y"].min(), atoms.data["y"].max())
-        )
-        print(
-            "Atoms Z min/max: %.1f, %.1f"
-            % (atoms.data["z"].min(), atoms.data["z"].max())
-        )
+        if len(atoms.data) > 0:
+            print(
+                "Atoms X min/max: %.1f, %.1f"
+                % (atoms.data["x"].min(), atoms.data["x"].max())
+            )
+            print(
+                "Atoms Y min/max: %.1f, %.1f"
+                % (atoms.data["y"].min(), atoms.data["y"].max())
+            )
+            print(
+                "Atoms Z min/max: %.1f, %.1f"
+                % (atoms.data["z"].min(), atoms.data["z"].max())
+            )
 
         if self.simulation["ice"] == True:
 
@@ -305,7 +308,7 @@ class ExitWaveImageSimulator(object):
         logger.info("Ideal image min/max: %f/%f" % (np.min(psi_tot), np.max(psi_tot)))
 
         # Get the timestamp
-        timestamp = time.time_ns() / 1e9
+        timestamp = time.time()
 
         # Set the metaadata
         metadata = self.metadata[index]
@@ -328,6 +331,7 @@ class ExitWaveImageSimulator(object):
         metadata["ice"] = self.simulation["ice"]
         metadata["damage_model"] = self.simulation["radiation_damage_model"]
         metadata["sensitivity_coefficient"] = self.simulation["sensitivity_coefficient"]
+        metadata["exposure_time"] = exposure_time
 
         # Compute the image scaled with Poisson noise
         return (index, image, metadata)
