@@ -148,12 +148,11 @@ def create_input_multislice(
     input_multislice.temporal_spatial_incoh = "Temporal_Spatial"
 
     # Condenser lens
-    # source spread function
+    # source spread (illumination semiangle) function
     ssf_sigma = multem.mrad_to_sigma(
-        input_multislice.E_0, microscope.beam.source_spread
+        input_multislice.E_0, microscope.beam.illumination_semiangle
     )
     input_multislice.cond_lens_si_sigma = ssf_sigma
-    print(ssf_sigma)
 
     # Objective lens
     input_multislice.obj_lens_m = microscope.lens.m
