@@ -9,6 +9,7 @@
 import parakeet.sample
 import argparse
 import multem
+import mrcfile
 import numpy as np
 import os.path
 import pandas
@@ -108,6 +109,7 @@ def create_input_multislice():
 
     # Set the energy
     input_multislice.E_0 = 300
+    input_multislice.bwl = False
 
     return input_multislice
 
@@ -298,7 +300,7 @@ def compute_expected_mean(size):
 
 def compute_mean_correction(ax=None):
     """
-    Compute the variance correction table
+    Compute the mean correction table
 
     """
 
@@ -327,6 +329,65 @@ def compute_mean_correction(ax=None):
     ax.set_title("Mean correction factor")
 
 
+def compute_mean_correction2(ax=None):
+    """
+    Compute the mean correction table
+
+    """
+
+    X = []
+    Y = []
+
+    # Loop through the pixel sizes
+    thickness = 20
+    for pixel_size in np.arange(0.1, 2.1, 0.1):
+
+        # Read the projected potential
+        handle = np.load("potential_%.1f_%d.npz" % (pixel_size, thickness))
+        potential = handle["potential"]
+        num_atoms = handle["num_atoms"]
+
+        # Select the pixels with potential in
+        xsize, ysize = potential.shape
+        x0 = 0  # xsize // 8
+        x1 = xsize  # 7 * x0
+        y0 = 0  # ysize // 8
+        y1 = ysize  # 7 * y0
+        potential = potential[x0:x1, y0:y1]
+
+        # Compute the density and variance
+        num_molecules = num_atoms / 3.0
+        ny, nx = potential.shape
+        area = (nx * pixel_size) * (ny * pixel_size)
+        mean = np.mean(potential)
+        density = num_molecules / (area)
+
+        # Append the pixel area and variance / density
+        X.append(pixel_size**2)
+        Y.append(mean / density)
+
+    X = np.array(X)
+    Y = np.array(Y)
+
+    # Extrapolate to zero and normalize
+    Y0 = Y[0] - X[0] * (Y[1] - Y[0]) / (X[1] - X[0])
+    Y = Y / Y0
+
+    X = [0] + list(X)
+    Y = [1.0] + list(Y)
+
+    # Write out the table to file
+    print("Mean0 = %f" % Y0)
+    with open("mean_table2.csv", "w") as outfile:
+        for x, y in zip(X, Y):
+            outfile.write("%.2f, %.7f\n" % (x, y))
+
+    # Plot
+    ax.plot(X, Y)
+    ax.set_xlabel(r"Pixel area ($Å^2$)" + "\n(c)")
+    ax.set_title("Mean correction factor")
+
+
 def compute_variance_correction(ax=None):
     """
     Compute the variance correction table
@@ -367,7 +428,7 @@ def compute_variance_correction(ax=None):
     X = np.array(X)
     Y = np.array(Y)
 
-    # Extrapolate to zero and nornalize
+    # Extrapolate to zero and normalize
     Y0 = Y[0] - X[0] * (Y[1] - Y[0]) / (X[1] - X[0])
     Y = Y / Y0
 
@@ -520,6 +581,7 @@ def calibrate():
     fig, ax = pylab.subplots(ncols=3, figsize=(width, height), constrained_layout=True)
     compute_power(ax[0])
     compute_mean_correction(ax[1])
+    # compute_mean_correction2(ax[1])
     compute_variance_correction(ax[2])
     fig.savefig("model.png", dpi=300, bbox_inches="tight")
 
@@ -568,10 +630,9 @@ def compute_exit_wave(atom_data, pixel_size):
     input_multislice = create_input_multislice()
 
     # Compute the number of pixels
-    nx = next_power_2(int(x_box_size / pixel_size))
-    ny = next_power_2(int(y_box_size / pixel_size))
-    assert nx <= 4096
-    assert ny <= 4096
+    nx = int(ceil(x_box_size / pixel_size) * 2)
+    ny = int(ceil(y_box_size / pixel_size) * 2)
+
     x_box_size = nx * pixel_size
     y_box_size = ny * pixel_size
     x_trans = (x_box_size - x_size) / 2.0 - x_min
@@ -585,7 +646,7 @@ def compute_exit_wave(atom_data, pixel_size):
     input_multislice.spec_lx = x_box_size
     input_multislice.spec_ly = y_box_size
     input_multislice.spec_lz = z_box_size
-    input_multislice.spec_dz = 5
+    input_multislice.spec_dz = 10
 
     # Set the specimen atoms
     input_multislice.spec_atoms = atom_data.to_multem()
@@ -622,6 +683,409 @@ def compute_exit_wave(atom_data, pixel_size):
     return physical_image, random_image, x0, x1
 
 
+def load_exit_wave(atom_data, ps):
+
+    physical_filename = "exit_wave_physical_%.1f.mrc" % ps
+    random_filename = "exit_wave_random_%.1f.mrc" % ps
+    metadata_filename = "metadata_%.1f.dat" % ps
+
+    if (
+        not os.path.exists(physical_filename)
+        or not os.path.exists(random_filename)
+        or not os.path.exists(metadata_filename)
+    ):
+        print("Simulating for pixel size: %.1f A" % ps)
+        physical_image, random_image, x0, x1 = compute_exit_wave(atom_data, ps)
+        physical_image_file = mrcfile.new(physical_filename, overwrite=True)
+        random_image_file = mrcfile.new(random_filename, overwrite=True)
+        physical_image_file.set_data(physical_image.astype("complex64"))
+        random_image_file.set_data(random_image.astype("complex64"))
+        with open(metadata_filename, "w") as outfile:
+            outfile.write("%f,%f,%f,%f" % (x0[0], x0[1], x1[0], x1[1]))
+    else:
+        print("Reading for pixel size: %.1f A" % ps)
+        physical_image = mrcfile.open(physical_filename).data
+        random_image = mrcfile.open(random_filename).data
+        with open(metadata_filename) as infile:
+            x00, x01, x10, x11 = map(float, infile.read().split(","))
+            x0 = (x00, x01)
+            x1 = (x10, x11)
+
+    return physical_image, random_image, x0, x1
+
+
+def plot_mean_and_var(physical_data, random_data, xmin, xmax, ps):
+
+    x0 = np.floor(xmin / ps).astype("int32")
+    x1 = np.floor(xmax / ps).astype("int32")
+    xr = x1 - x0
+    x0 = x0 + xr // 3
+    x1 = x1 - xr // 3
+
+    random_middle = random_data[x0[0] : x1[0], x0[1] : x1[1]]
+    physical_middle = physical_data[x0[0] : x1[0], x0[1] : x1[1]]
+
+    physical_middle_real = physical_middle.flatten().real
+    physical_middle_imag = physical_middle.flatten().imag
+    random_middle_real = random_middle.flatten().real
+    random_middle_imag = random_middle.flatten().imag
+
+    # physical_middle_real = np.angle(physical_middle.flatten())
+    # physical_middle_imag = np.angle(physical_middle.flatten())
+    # random_middle_real = np.abs(random_middle.flatten())
+    # random_middle_imag = np.abs(random_middle.flatten())
+
+    physical_middle_mean_real = np.mean(physical_middle_real)
+    physical_middle_mean_imag = np.mean(physical_middle_imag)
+    random_middle_mean_real = np.mean(random_middle_real)
+    random_middle_mean_imag = np.mean(random_middle_imag)
+
+    physical_middle_std_real = np.std(physical_middle_real)
+    physical_middle_std_imag = np.std(physical_middle_imag)
+    random_middle_std_real = np.std(random_middle_real)
+    random_middle_std_imag = np.std(random_middle_imag)
+
+    width = 0.0393701 * 190
+    height = width * 0.75
+    fig, ax = pylab.subplots(
+        figsize=(width, height),
+        nrows=2,
+        ncols=2,
+        sharex=True,
+        sharey=True,
+        constrained_layout=True,
+    )
+    ax[0][0].hist(physical_middle.flatten().real, bins=20, density=True)
+    ax[0][1].hist(physical_middle.flatten().imag, bins=20, density=True)
+    ax[1][0].hist(random_middle.flatten().real, bins=20, density=True)
+    ax[1][1].hist(random_middle.flatten().imag, bins=20, density=True)
+    ax[0][0].set_title("Real component", fontweight="bold")
+    ax[0][1].set_title("Imaginary component", fontweight="bold")
+    ax[0][0].set_ylabel("Physical model", fontweight="bold")
+    ax[1][0].set_ylabel("Random model", fontweight="bold")
+    ax[0][0].set_xlabel("(a)")
+    ax[0][1].set_xlabel("(b)")
+    ax[1][0].set_xlabel("(c)")
+    ax[1][1].set_xlabel("(d)")
+    ax[0][0].axvline(physical_middle_mean_real, color="black")
+    ax[0][1].axvline(physical_middle_mean_imag, color="black")
+    ax[1][0].axvline(random_middle_mean_real, color="black")
+    ax[1][1].axvline(random_middle_mean_imag, color="black")
+    # ymax = ax[0][0].get_ylim()[1]
+    if ps == 1.0:
+        xr = 0.8
+        xi = 0.4
+    else:
+        xr = 0.5
+        xi = -1.0
+    ax[0][0].text(
+        xr,
+        0.5 * ax[0][0].get_ylim()[1],
+        "mean: %.2f\n sdev: %.2f"
+        % (physical_middle_mean_real, physical_middle_std_real),
+    )
+    ax[0][1].text(
+        xi,
+        0.5 * ax[0][1].get_ylim()[1],
+        "mean: %.2f\n sdev: %.2f"
+        % (physical_middle_mean_imag, physical_middle_std_imag),
+    )
+    ax[1][0].text(
+        xr,
+        0.5 * ax[1][0].get_ylim()[1],
+        "mean: %.2f\n sdev: %.2f" % (random_middle_mean_real, random_middle_std_real),
+    )
+    ax[1][1].text(
+        xi,
+        0.5 * ax[1][1].get_ylim()[1],
+        "mean: %.2f\n sdev: %.2f" % (random_middle_mean_imag, random_middle_std_imag),
+    )
+    fig.savefig("histograms_%.1fA.png" % ps, dpi=300, bbox_inches="tight")
+    pylab.close("all")
+
+    return (
+        physical_middle_mean_real,
+        physical_middle_mean_imag,
+        physical_middle_std_real,
+        physical_middle_std_imag,
+        random_middle_mean_real,
+        random_middle_mean_imag,
+        random_middle_std_real,
+        random_middle_std_imag,
+    )
+
+
+def plot_power(physical_data, random_data, xmin, xmax, ps):
+
+    x0 = np.floor(xmin / ps).astype("int32")
+    x1 = np.floor(xmax / ps).astype("int32")
+    xr = x1 - x0
+    x0 = x0 + xr // 3
+    x1 = x1 - xr // 3
+
+    random_middle = random_data[x0[0] : x1[0], x0[1] : x1[1]]
+    physical_middle = physical_data[x0[0] : x1[0], x0[1] : x1[1]]
+    physical_middle_mean_real = np.mean(physical_middle.flatten().real)
+    physical_middle_mean_imag = np.mean(physical_middle.flatten().imag)
+    random_middle_mean_real = np.mean(random_middle.flatten().real)
+    random_middle_mean_imag = np.mean(random_middle.flatten().imag)
+
+    # pylab.imshow(np.abs(random_data))
+    # pylab.show()
+    # pylab.imshow(np.abs(physical_data))
+    # pylab.show()
+
+    def compute_power(data, pixel_size):
+        f = np.fft.fft2(data)
+        p = np.abs(f) ** 2
+        p = np.fft.fftshift(p)
+
+        r = radial_average(p)[0 : data.shape[0] // 2]
+        d = np.arange(r.size) / (pixel_size * data.shape[0])
+
+        N = np.mean(r[d < 0.5][1:])
+
+        return d[1:], r[1:] / N
+
+    random_d, random_power = compute_power(random_middle, ps)
+    physical_d, physical_power = compute_power(physical_middle, ps)
+
+    width = 0.0393701 * 190
+    height = width * 0.74
+    fig, ax = pylab.subplots(figsize=(width, height), constrained_layout=True)
+    ax.plot(physical_d, physical_power, label="Physical model")
+    ax.plot(random_d, random_power, label="Random model")
+    ax.set_xlabel("Spatial frequency (1/Å)")
+    ax.set_ylabel("Power spectrum")
+    # ax.set_xlim(0, 1.0)
+    ax.legend()
+    fig.savefig("power_%.1fA.png" % ps, dpi=300, bbox_inches="tight")
+    pylab.close("all")
+
+    return physical_d, physical_power, random_d, random_power
+
+
+def plot_edge(physical_data, random_data, xmin, xmax, ps):
+
+    x0 = np.floor(xmin / ps).astype("int32")
+    x1 = np.floor(xmax / ps).astype("int32")
+    xd = x1 - x0
+    x0 = x0 - xd // 10
+    x1 = x0 + 3 * xd // 10
+
+    # x1 = 2 * x0  # + x0 // 2
+    # x0[:] = 0  # x0 // 2
+    random_edge = random_data[x0[0] : x1[0], x0[1] : x1[1]]
+    physical_edge = physical_data[x0[0] : x1[0], x0[1] : x1[1]]
+    width = 0.0393701 * 190
+    height = width
+    fig, ax = pylab.subplots(figsize=(width, height), ncols=2, constrained_layout=True)
+    vmin = min(np.min(np.abs(random_edge)), np.min(np.abs(physical_edge)))
+    vmax = max(np.max(np.abs(random_edge)), np.max(np.abs(physical_edge)))
+    ax[0].imshow(np.abs(physical_edge), vmin=vmin, vmax=vmax, cmap="gray_r")
+    ax[1].imshow(np.abs(random_edge), vmin=vmin, vmax=vmax, cmap="gray_r")
+    ax[0].set_title("Physical model", fontweight="bold")
+    ax[1].set_title("Random model", fontweight="bold")
+    ax[0].set_xticks([])
+    ax[1].set_xticks([])
+    ax[0].set_yticks([])
+    ax[1].set_yticks([])
+    ax[0].set_xlabel("(a)")
+    ax[1].set_xlabel("(b)")
+    fig.savefig("edge_%.1fA.png" % ps, dpi=300, bbox_inches="tight")
+    pylab.close("all")
+    # pylab.show()
+
+    return np.abs(random_edge), np.abs(physical_edge)
+
+
+def plot_all_mean_and_std(pixel_size, stats_list):
+    """
+    Make a plot of mean and std vs pixel size
+
+    """
+
+    # Extract the stats
+    (
+        p_real,
+        p_imag,
+        p_real_std,
+        p_imag_std,
+        r_real,
+        r_imag,
+        r_real_std,
+        r_imag_std,
+    ) = map(np.array, zip(*stats_list))
+
+    width = 0.0393701 * 190
+    height = width
+    fig, ax = pylab.subplots(figsize=(width, height), constrained_layout=True)
+    l1 = ax.plot(pixel_size, p_real, label="Physical (real)")
+    l2 = ax.plot(pixel_size, p_imag, label="Physical (imag)")
+    l3 = ax.plot(pixel_size, r_real, label="Random (real)")
+    l4 = ax.plot(pixel_size, r_imag, label="Random (imag)")
+    ax.fill_between(
+        pixel_size,
+        p_real - p_real_std,
+        p_real + p_real_std,
+        color=l1[0].get_color(),
+        alpha=0.3,
+    )
+    ax.fill_between(
+        pixel_size,
+        p_imag - p_imag_std,
+        p_imag + p_imag_std,
+        color=l2[0].get_color(),
+        alpha=0.3,
+    )
+    ax.fill_between(
+        pixel_size,
+        r_real - r_real_std,
+        r_real + r_real_std,
+        color=l3[0].get_color(),
+        alpha=0.3,
+    )
+    ax.fill_between(
+        pixel_size,
+        r_imag - r_imag_std,
+        r_imag + r_imag_std,
+        color=l4[0].get_color(),
+        alpha=0.3,
+    )
+    ax.legend(loc="lower right")
+    ax.set_xlabel("Pixel size (A)")
+    ax.set_ylabel("Exit wave mean and standard deviation")
+    fig.savefig("mean_and_std.png", dpi=300, bbox_inches="tight")
+    pylab.close("all")
+
+
+def plot_all_power(pixel_size, power_list):
+    """
+    Plot all the power spectra
+
+    """
+    cycle = pylab.rcParams["axes.prop_cycle"].by_key()["color"]
+    width = 0.0393701 * 190
+    height = width
+    fig, ax = pylab.subplots(figsize=(width, height), constrained_layout=True)
+    for ps, power in zip(pixel_size, power_list):
+        p1 = ax.plot(power[0], power[1], color=cycle[0], alpha=0.5)
+        p2 = ax.plot(power[2], power[3], color=cycle[1], alpha=0.5)
+    ax.set_xlabel("Spatial frequency (1/Å)")
+    ax.set_ylabel("Power spectrum")
+    ax.legend(handles=[p1[0], p2[0]], labels=["Physical", "Random"])
+    ax.set_xlim(0, 1.0)
+    # pylab.show()
+    fig.savefig("power.png", dpi=300, bbox_inches="tight")
+    pylab.close("all")
+
+
+def plot_all_mean_and_power(pixel_size, stats_list, power_list):
+    """
+    Make a plot of mean and std and power vs pixel size
+
+    """
+
+    # Extract the stats
+    (
+        p_real,
+        p_imag,
+        p_real_std,
+        p_imag_std,
+        r_real,
+        r_imag,
+        r_real_std,
+        r_imag_std,
+    ) = map(np.array, zip(*stats_list))
+
+    width = 0.0393701 * 190
+    height = (4 / 8) * width
+    fig, ax = pylab.subplots(figsize=(width, height), ncols=2, constrained_layout=True)
+    l1 = ax[0].plot(pixel_size, p_real, label="Physical (real)")
+    l2 = ax[0].plot(pixel_size, p_imag, label="Physical (imag)")
+    l3 = ax[0].plot(pixel_size, r_real, label="Random (real)")
+    l4 = ax[0].plot(pixel_size, r_imag, label="Random (imag)")
+    ax[0].fill_between(
+        pixel_size,
+        p_real - p_real_std,
+        p_real + p_real_std,
+        color=l1[0].get_color(),
+        alpha=0.3,
+    )
+    ax[0].fill_between(
+        pixel_size,
+        p_imag - p_imag_std,
+        p_imag + p_imag_std,
+        color=l2[0].get_color(),
+        alpha=0.3,
+    )
+    ax[0].fill_between(
+        pixel_size,
+        r_real - r_real_std,
+        r_real + r_real_std,
+        color=l3[0].get_color(),
+        alpha=0.3,
+    )
+    ax[0].fill_between(
+        pixel_size,
+        r_imag - r_imag_std,
+        r_imag + r_imag_std,
+        color=l4[0].get_color(),
+        alpha=0.3,
+    )
+    ax[0].legend(loc="lower right")
+    ax[0].set_xlabel("Pixel size (A)\n(a)")
+    ax[0].set_ylabel("Exit wave mean and standard deviation")
+
+    cycle = pylab.rcParams["axes.prop_cycle"].by_key()["color"]
+    for ps, power in zip(pixel_size, power_list):
+        p1 = ax[1].plot(power[0], power[1], color=cycle[0], alpha=0.5)
+        p2 = ax[1].plot(power[2], power[3], color=cycle[1], alpha=0.5)
+    ax[1].set_xlabel("Spatial frequency (1/Å)\n(b)")
+    ax[1].set_ylabel("Power spectrum")
+    ax[1].legend(handles=[p1[0], p2[0]], labels=["Physical", "Random"])
+    ax[1].set_xlim(0, 1.0)
+    # pylab.show()
+    fig.savefig("mean_and_power.png", dpi=300, bbox_inches="tight")
+    pylab.close("all")
+
+
+def plot_all_edge(pixel_size, edge_list):
+
+    width = 0.0393701 * 190
+    height = 0.5 * width
+    fig, ax = pylab.subplots(
+        figsize=(width, height), ncols=4, nrows=2, constrained_layout=True
+    )
+
+    pixel_size = [pixel_size[i] for i in [0, 3, 6, 9]]
+    edge_list = [edge_list[i] for i in [0, 3, 6, 9]]
+
+    for i, (ps, edge) in enumerate(zip(pixel_size, edge_list)):
+
+        vmin = min(np.min(edge[0]), np.min(edge[0]))
+        vmax = max(np.max(edge[1]), np.max(edge[1]))
+
+        ax[0][i].imshow(edge[0], vmin=vmin, vmax=vmax, cmap="gray_r")
+        ax[1][i].imshow(edge[1], vmin=vmin, vmax=vmax, cmap="gray_r")
+        # ax[0][i].set_title("Physical model", fontweight="bold")
+        # ax[1][i].set_title("Random model", fontweight="bold")
+        ax[0][i].set_xticks([])
+        ax[1][i].set_xticks([])
+        ax[0][i].set_yticks([])
+        ax[1][i].set_yticks([])
+        ax[0][i].set_xlabel("(%s)" % "abcd"[i])
+        ax[1][i].set_xlabel("(%s)" % "efgh"[i])
+        ax[0][i].set_title("%.1f Å" % ps)
+
+    ax[0][0].set_ylabel("Physical model")
+    ax[1][0].set_ylabel("Random model")
+
+    fig.savefig("edge.png" % ps, dpi=300, bbox_inches="tight")
+    pylab.close("all")
+    # pylab.show()
+
+
 def validate():
     """
     Validate the ice model
@@ -631,145 +1095,31 @@ def validate():
     # Load the water model
     atom_data = load_water_atomic_model()
 
-    pixel_size = [1.0, 0.1]
+    # Set the pixel sizes
+    pixel_size = np.arange(0.1, 1.1, 0.1)  # [0.1]#, 1.0]
+
+    stats_list = []
+    power_list = []
+    edge_list = []
 
     for ps in pixel_size:
 
         # Get the simulated exit wave
-        physical_data, random_data, xmin, xmax = compute_exit_wave(atom_data, ps)
+        physical_data, random_data, xmin, xmax = load_exit_wave(atom_data, ps)
 
-        x0 = np.floor(xmin / ps).astype("int32")
-        x1 = np.floor(xmax / ps).astype("int32")
-        xr = x1 - x0
-        x0 = x0 + xr // 4
-        x1 = x1 - xr // 4
+        # Make the plots
+        stats = plot_mean_and_var(physical_data, random_data, xmin, xmax, ps)
+        power = plot_power(physical_data, random_data, xmin, xmax, ps)
+        edge = plot_edge(physical_data, random_data, xmin, xmax, ps)
 
-        random_middle = random_data[x0[0] : x1[0], x0[1] : x1[1]]
-        physical_middle = physical_data[x0[0] : x1[0], x0[1] : x1[1]]
-        physical_middle_mean_real = np.mean(physical_middle.flatten().real)
-        physical_middle_mean_imag = np.mean(physical_middle.flatten().imag)
-        random_middle_mean_real = np.mean(random_middle.flatten().real)
-        random_middle_mean_imag = np.mean(random_middle.flatten().imag)
+        stats_list.append(stats)
+        power_list.append(power)
+        edge_list.append(edge)
 
-        # pylab.imshow(np.abs(random_middle))
-        # pylab.show()
-        # pylab.imshow(np.abs(physical_middle))
-        # pylab.show()
-        # continue
-
-        physical_middle_std_real = np.std(physical_middle.flatten().real)
-        physical_middle_std_imag = np.std(physical_middle.flatten().imag)
-        random_middle_std_real = np.std(random_middle.flatten().real)
-        random_middle_std_imag = np.std(random_middle.flatten().imag)
-
-        # print("Hola")
-        width = 0.0393701 * 190
-        height = width * 0.75
-        fig, ax = pylab.subplots(
-            figsize=(width, height),
-            nrows=2,
-            ncols=2,
-            sharex=True,
-            sharey=True,
-            constrained_layout=True,
-        )
-        ax[0][0].hist(physical_middle.flatten().real, bins=20, density=True)
-        ax[0][1].hist(physical_middle.flatten().imag, bins=20, density=True)
-        ax[1][0].hist(random_middle.flatten().real, bins=20, density=True)
-        ax[1][1].hist(random_middle.flatten().imag, bins=20, density=True)
-        ax[0][0].set_title("Real component", fontweight="bold")
-        ax[0][1].set_title("Imaginary component", fontweight="bold")
-        ax[0][0].set_ylabel("Physical model", fontweight="bold")
-        ax[1][0].set_ylabel("Random model", fontweight="bold")
-        ax[0][0].set_xlabel("(a)")
-        ax[0][1].set_xlabel("(b)")
-        ax[1][0].set_xlabel("(c)")
-        ax[1][1].set_xlabel("(d)")
-        ax[0][0].axvline(physical_middle_mean_real, color="black")
-        ax[0][1].axvline(physical_middle_mean_imag, color="black")
-        ax[1][0].axvline(random_middle_mean_real, color="black")
-        ax[1][1].axvline(random_middle_mean_imag, color="black")
-        # ymax = ax[0][0].get_ylim()[1]
-        if ps == 1.0:
-            xr = 0.8
-            xi = 0.4
-        else:
-            xr = 0.5
-            xi = -1.0
-        ax[0][0].text(
-            xr,
-            0.5 * ax[0][0].get_ylim()[1],
-            "mean: %.2f\n sdev: %.2f"
-            % (physical_middle_mean_real, physical_middle_std_real),
-        )
-        ax[0][1].text(
-            xi,
-            0.5 * ax[0][1].get_ylim()[1],
-            "mean: %.2f\n sdev: %.2f"
-            % (physical_middle_mean_imag, physical_middle_std_imag),
-        )
-        ax[1][0].text(
-            xr,
-            0.5 * ax[1][0].get_ylim()[1],
-            "mean: %.2f\n sdev: %.2f"
-            % (random_middle_mean_real, random_middle_std_real),
-        )
-        ax[1][1].text(
-            xi,
-            0.5 * ax[1][1].get_ylim()[1],
-            "mean: %.2f\n sdev: %.2f"
-            % (random_middle_mean_imag, random_middle_std_imag),
-        )
-        fig.savefig("histograms_%.1fA.png" % ps, dpi=300, bbox_inches="tight")
-
-        def compute_power(data, pixel_size):
-            f = np.fft.fft2(data)
-            p = np.abs(f) ** 2
-            p = np.fft.fftshift(p)
-
-            r = radial_average(p)[0 : data.shape[0] // 2]
-            d = np.arange(r.size) / (pixel_size * data.shape[0])
-            return d[1:], r[1:]
-
-        random_d, random_power = compute_power(random_middle, ps)
-        physical_d, physical_power = compute_power(physical_middle, ps)
-
-        width = 0.0393701 * 190
-        height = width * 0.74
-        fig, ax = pylab.subplots(figsize=(width, height), constrained_layout=True)
-        ax.plot(physical_d, physical_power, label="Physical model")
-        ax.plot(random_d, random_power, label="Random model")
-        ax.set_xlabel("Spatial frequency (1/Å)")
-        ax.set_ylabel("Power spectrum")
-        ax.set_xlim(0, 0.5)
-        ax.legend()
-        fig.savefig("power_%.1fA.png" % ps, dpi=300, bbox_inches="tight")
-
-        x0 = np.floor(xmin / ps).astype("int32")
-        # x1 = np.floor(xmax / ps).astype("int32")
-        x1 = 2 * x0  # + x0 // 2
-        x0[:] = 0  # x0 // 2
-        random_edge = random_data[x0[0] : x1[0], x0[1] : x1[1]]
-        physical_edge = physical_data[x0[0] : x1[0], x0[1] : x1[1]]
-        width = 0.0393701 * 190
-        height = width
-        fig, ax = pylab.subplots(
-            figsize=(width, height), ncols=2, constrained_layout=True
-        )
-        vmin = min(np.min(np.abs(random_edge)), np.min(np.abs(physical_edge)))
-        vmax = max(np.max(np.abs(random_edge)), np.max(np.abs(physical_edge)))
-        ax[0].imshow(np.abs(physical_edge), vmin=vmin, vmax=vmax)
-        ax[1].imshow(np.abs(random_edge), vmin=vmin, vmax=vmax)
-        ax[0].set_title("Physical model", fontweight="bold")
-        ax[1].set_title("Random model", fontweight="bold")
-        ax[0].set_xticks([])
-        ax[1].set_xticks([])
-        ax[0].set_yticks([])
-        ax[1].set_yticks([])
-        ax[0].set_xlabel("(a)")
-        ax[1].set_xlabel("(b)")
-        fig.savefig("edge_%.1fA.png" % ps, dpi=300, bbox_inches="tight")
-        # pylab.show()
+    # plot_all_mean_and_std(pixel_size, stats_list)
+    # plot_all_power(pixel_size, power_list)
+    plot_all_mean_and_power(pixel_size, stats_list, power_list)
+    plot_all_edge(pixel_size, edge_list)
 
 
 if __name__ == "__main__":
