@@ -43,6 +43,34 @@ def test_new(tmp_path):
     config = parakeet.config.new(filename)
 
 
+def test_edit(tmp_path):
+
+    filename = os.path.join(tmp_path, "tmp.yaml")
+    config = parakeet.config.new(filename)
+    config = parakeet.config.edit(
+        filename,
+        config_obj="""
+        sample:
+            box:
+                - 2000
+                - 2000
+                - 2000
+    """,
+    )
+    config = parakeet.config.edit(
+        filename,
+        config_obj="""
+        sample:
+            molecules:
+                pdb:
+                    - id: 4v1w
+                      instances: 1
+    """,
+    )
+    assert config.sample.molecules.pdb[0].id == "4v1w"
+    assert config.sample.box[0] == 2000
+
+
 def test_load(tmp_path):
 
     filename = os.path.join(tmp_path, "tmp.yaml")
